summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/database.rs20
-rw-r--r--src/kona-cli.rs (renamed from src/birka-cli.rs)22
-rw-r--r--src/kona-web.rs (renamed from src/birka-web.rs)22
3 files changed, 32 insertions, 32 deletions
diff --git a/src/database.rs b/src/database.rs
index c7c84a0..0702ed9 100644
--- a/src/database.rs
+++ b/src/database.rs
@@ -1,19 +1,19 @@
// Copyright © 2020 Jakob L. Kreuze <zerodaysfordays@sdf.org>
//
-// This file is part of бирка-тян.
+// This file is part of Kona.
//
-// бирка-тян is free software; you can redistribute it and/or modify it
-// under the terms of the GNU Affero General Public License as published
-// by the Free Software Foundation; either version 3 of the License, or
-// (at your option) any later version.
+// Kona is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Affero General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or (at
+// your option) any later version.
//
-// бирка-тян is distributed in the hope that it will be useful, but
-// WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// Affero General Public License for more details.
+// Kona is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public
+// License for more details.
//
// You should have received a copy of the GNU Affero General Public
-// License along with бирка-тян. If not, see <http://www.gnu.org/licenses/>.
+// License along with Kona. If not, see <http://www.gnu.org/licenses/>.
use anyhow::Result;
use rusqlite::Connection;
diff --git a/src/birka-cli.rs b/src/kona-cli.rs
index 4a8681f..04adfc8 100644
--- a/src/birka-cli.rs
+++ b/src/kona-cli.rs
@@ -1,19 +1,19 @@
// Copyright © 2020 Jakob L. Kreuze <zerodaysfordays@sdf.org>
//
// This file is part of бирка-тян.
//
// бирка-тян is free software; you can redistribute it and/or modify it
// under the terms of the GNU Affero General Public License as published
// by the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// бирка-тян is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public
-// License along with бирка-тян. If not, see <http://www.gnu.org/licenses/>.
+// License along with Kona. If not, see <http://www.gnu.org/licenses/>.
#[macro_use]
extern crate anyhow;
@@ -54,7 +54,7 @@ fn main() {
} else if let Ok(path) = std::env::var("TB_PATH") {
TagDatabase::new(path)
} else {
- TagDatabase::new("./birka.db")
+ TagDatabase::new("./kona.db")
}
.unwrap();
@@ -1,19 +1,19 @@
// Copyright © 2020 Jakob L. Kreuze <zerodaysfordays@sdf.org>
//
-// This file is part of бирка-тян.
+// This file is part of Kona.
//
@@ -1,19 +1,19 @@
//
-// бирка-тян is free software; you can redistribute it and/or modify it
-// under the terms of the GNU Affero General Public License as published
-// by the Free Software Foundation; either version 3 of the License, or
-// (at your option) any later version.
+// Kona is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Affero General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or (at
+// your option) any later version.
//
@@ -1,19 +1,19 @@
//
-// бирка-тян is distributed in the hope that it will be useful, but
-// WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// Affero General Public License for more details.
+// Kona is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public
+// License for more details.
//
// You should have received a copy of the GNU Affero General Public
diff --git a/src/birka-web.rs b/src/kona-web.rs
index cd68923..2d63772 100644
--- a/src/birka-web.rs
+++ b/src/kona-web.rs
@@ -1,19 +1,19 @@
// Copyright © 2020 Jakob L. Kreuze <zerodaysfordays@sdf.org>
//
// This file is part of бирка-тян.
//
// бирка-тян is free software; you can redistribute it and/or modify it
// under the terms of the GNU Affero General Public License as published
// by the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// бирка-тян is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public
-// License along with бирка-тян. If not, see <http://www.gnu.org/licenses/>.
+// License along with Kona. If not, see <http://www.gnu.org/licenses/>.
#![feature(proc_macro_hygiene, decl_macro)]
@@ -70,7 +70,7 @@ impl DatabaseConnection {
let bin = std::env::current_exe()?.canonicalize()?;
let bin_dir = bin.parent().unwrap();
let file_dir = bin_dir.join("files/").to_str().unwrap().to_string();
- let tb = TagDatabase::new(&bin_dir.join("birka.db"))?;
+ let tb = TagDatabase::new(&bin_dir.join("kona.db"))?;
Ok(DatabaseConnection { tb, file_dir })
}
}
@@ -1,19 +1,19 @@
// Copyright © 2020 Jakob L. Kreuze <zerodaysfordays@sdf.org>
//
-// This file is part of бирка-тян.
+// This file is part of Kona.
//
@@ -1,19 +1,19 @@
//
-// бирка-тян is free software; you can redistribute it and/or modify it
-// under the terms of the GNU Affero General Public License as published
-// by the Free Software Foundation; either version 3 of the License, or
-// (at your option) any later version.
+// Kona is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Affero General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or (at
+// your option) any later version.
//
@@ -1,19 +1,19 @@
//
-// бирка-тян is distributed in the hope that it will be useful, but
-// WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// Affero General Public License for more details.
+// Kona is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public
+// License for more details.
//
// You should have received a copy of the GNU Affero General Public